@@ -124,16 +124,16 @@ class QASquadExplainaboardBuilder:
             confidence_score_low = 0
             confidence_score_up = 0
             overall_performance = Performance(
-                                                   metric_name=metric_name,
-                                                   value=format(overall_value, '.4g'),
-                                                   confidence_score_low=format(confidence_score_low, '.4g'),
-                                                   confidence_score_up=format(confidence_score_up, '.4g')
+                                   metric_name=metric_name,
+                                   value=float(format(overall_value, '.4g')),
+                                   confidence_score_low=float(format(confidence_score_low, '.4g')),
+                                   confidence_score_up=float(format(confidence_score_up, '.4g')),
             )
-
             if self._info.results.overall == None:
-                self._info.results.overall = [overall_performance]
+                self._info.results.overall = {}
+                self._info.results.overall[metric_name] = overall_performance
             else:
-                self._info.results.overall.append(overall_performance)
+                self._info.results.overall[metric_name] = overall_performance
 
 
     def _bucketing_samples(self, sysout_iterator):
@@ -261,7 +261,6 @@ class QASquadExplainaboardBuilder:
     def _print_bucket_info(self):
         for feature_name in self._performances_over_bucket.keys():
             print_dict(self._performances_over_bucket[feature_name], feature_name)
-        print("")
 
 
     def run(self):
