@@ -1,6 +1,6 @@
 from typing import Any, Iterable, Optional
-from explainaboard.constants import TaskType
 from explainaboard import feature
+from explainaboard.tasks import TaskType
 from explainaboard.info import SysOutputInfo
 
 
